==> openshift-model-operator-5.2.0-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/IngressControllerLoggingFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class IngressControllerLoggingFluentImpl<A extends IngressControllerLoggingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IngressControllerLoggingFluent<A> {

    private AccessLoggingBuilder access;

    public IngressControllerLoggingFluentImpl() {
    }

    public IngressControllerLoggingFluentImpl(IngressControllerLogging instance) {
        this.withAccess(instance.getAccess()); 
    }

    
/**
 * This method has been deprecated, please use method buildAccess instead.
 * @return The buildable object.
 */
@Deprecated public AccessLogging getAccess() {
        return this.access!=null?this.access.build():null;
    }

    public AccessLogging buildAccess() {
        return this.access!=null?this.access.build():null;
    }

    public A withAccess(AccessLogging access) {
        _visitables.get("access").remove(this.access);
        if (access!=null){ this.access= new AccessLoggingBuilder(access); _visitables.get("access").add(this.access);} return (A) this;
    }

    public Boolean hasAccess() {
        return this.access != null;
    }

    public IngressControllerLoggingFluent.AccessNested<A> withNewAccess() {
        return new AccessNestedImpl();
    }

    public IngressControllerLoggingFluent.AccessNested<A> withNewAccessLike(AccessLogging item) {
        return new AccessNestedImpl(item);
    }

    public IngressControllerLoggingFluent.AccessNested<A> editAccess() {
        return withNewAccessLike(getAccess());
    }

    public IngressControllerLoggingFluent.AccessNested<A> editOrNewAccess() {
        return withNewAccessLike(getAccess() != null ? getAccess(): new AccessLoggingBuilder().build());
    }

    public IngressControllerLoggingFluent.AccessNested<A> editOrNewAccessLike(AccessLogging item) {
        return withNewAccessLike(getAccess() != null ? getAccess(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IngressControllerLoggingFluentImpl that = (IngressControllerLoggingFluentImpl) o;
        if (access != null ? !access.equals(that.access) :that.access != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(access,  super.hashCode());
    }

    public class AccessNestedImpl<N> extends AccessLoggingFluentImpl<IngressControllerLoggingFluent.AccessNested<N>> implements IngressControllerLoggingFluent.AccessNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final AccessLoggingBuilder builder;

            AccessNestedImpl(AccessLogging item) {
                this.builder = new AccessLoggingBuilder(this, item);
                        
            }

            AccessNestedImpl() {
                this.builder = new AccessLoggingBuilder(this);
                        
            }

            public N and() {
                return (N) IngressControllerLoggingFluentImpl.this.withAccess(builder.build());
            }

            public N endAccess() {
                return and();
            }
    }


}

==> openshift-model-operator-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/IngressControllerLoggingFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class IngressControllerLoggingFluentImpl<A extends IngressControllerLoggingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IngressControllerLoggingFluent<A> {

    private AccessLoggingBuilder access;

    public IngressControllerLoggingFluentImpl() {
    }

    public IngressControllerLoggingFluentImpl(IngressControllerLogging instance) {
        this.withAccess(instance.getAccess()); 
    }

    
/**
 * This method has been deprecated, please use method buildAccess instead.
 * @return The buildable object.
 */
@Deprecated public AccessLogging getAccess() {
        return this.access!=null?this.access.build():null;
    }

    public AccessLogging buildAccess() {
        return this.access!=null?this.access.build():null;
    }

    public A withAccess(AccessLogging access) {
        _visitables.get("access").remove(this.access);
        if (access!=null){ this.access= new AccessLoggingBuilder(access); _visitables.get("access").add(this.access);} return (A) this;
    }

    public Boolean hasAccess() {
        return this.access != null;
    }

    public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> withNewAccess() {
        return new AccessNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> withNewAccessLike(AccessLogging item) {
        return new AccessNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editAccess() {
        return withNewAccessLike(getAccess());
    }

    public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editOrNewAccess() {
        return withNewAccessLike(getAccess() != null ? getAccess(): new AccessLoggingBuilder().build());
    }

    public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editOrNewAccessLike(AccessLogging item) {
        return withNewAccessLike(getAccess() != null ? getAccess(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IngressControllerLoggingFluentImpl that = (IngressControllerLoggingFluentImpl) o;
        if (access != null ? !access.equals(that.access) :that.access != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(access,  super.hashCode());
    }

    public class AccessNestedImpl<N> extends AccessLoggingFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final AccessLoggingBuilder builder;

            AccessNestedImpl(AccessLogging item) {
                this.builder = new AccessLoggingBuilder(this, item);
                        
            }

            AccessNestedImpl() {
                this.builder = new AccessLoggingBuilder(this);
                        
            }

            public N and() {
                return (N) IngressControllerLoggingFluentImpl.this.withAccess(builder.build());
            }

            public N endAccess() {
                return and();
            }
    }


}
